<a name="readme-top"></a>

<!-- Presentation Block -->
<br />

<div align="center">

  <a href="https://github.com/LightDestory/RepositoryTemplate">
    <img src=".github/assets/images/presentation_image.gif" alt="Preview" width="90%">
  </a>

  <h2 align="center">NIF Dumper</h2>
  
  <p align="center">
      A simple Python CLI tool to search and download NIF (Naruto Italian Forum) releases
  </p>
  
  <br />
  <br />

</div>

<!-- ToC -->

<details>
  <summary>Table of Contents</summary>
  <ol>
    <li>
      <a href="#book-about-the-project">📖 About The Project</a>
    </li>
    <li>
      <a href="#gear-getting-started">⚙️ Getting Started</a>
      <ul>
        <li><a href="#prerequisites">Prerequisites</a></li>
        <li><a href="#installation">Installation</a></li>
        <li><a href="#usage">Usage</a></li>
      </ul>
    </li>
    <li><a href="#dizzy-contributing">💫 Contributing</a></li>
    <li><a href="#handshake-support">🤝 Support</a></li>
    <li><a href="#warning-license">⚠️ License</a></li>
    <li><a href="#hammer_and_wrench-built-with">🛠️ Built With</a></li>
  </ol>
</details>

<!-- About Block -->

## :book: About The Project

A simple Python CLI tool to search and download NIF (Naruto Italian Forum) releases.

_This utility aims to make easier the download of a whole series due to missing pack downloads_

If you like NIF releases, support the team!

__This project is in no way affiliated with, supported or offered by NIF Team__

<p align="right">(<a href="#readme-top">back to top</a>)</p>

<!-- Setup Block -->

## :gear: Getting Started

### Prerequisites

__Make sure to have Python 3.7+ and aria2 installed on your system.__

<p align="right">(<a href="#readme-top">back to top</a>)</p>

### Installation
You can install this tool as a Python Module using `pip`
or executing the script directly.

- If you want to install the tool as a Python Module:
    - Install the module using pip: `pip install nif-dumper`
    - You can run the tool using: `nif-dumper`
- If you want to use the script directly:
    - Clone the repository anywhere on your pc:

      `git clone https://github.com/LightDestory/NIF-Dumper`

    - Install the requirements using `pip` (create a `venv` if you want):

      `pip install .`

    - Run the dumper:

      `python ./src/nif_dumper/dumper.py`

<p align="right">(<a href="#readme-top">back to top</a>)</p>

### Usage

The dumper provides a wizard that will help you to download the releases.

<p align="right">(<a href="#readme-top">back to top</a>)</p>

<!-- Contribute Block -->

## :dizzy: Contributing

If you are interested in contributing, please refer to [Contributing Guidelines](.github/CONTRIBUTING.md) for more information and take a look at open issues. Ask any questions you may have and you will be provided guidance on how to get started.

Thank you for considering contributing.

<p align="right">(<a href="#readme-top">back to top</a>)</p>

<!-- Support Block -->

## :handshake: Support

If you find value in my work, please consider making a donation to help me create, and improve my projects.

Your donation will go a long way in helping me continue to create free software that can benefit people around the world.

<p align="center">
<a href='https://ko-fi.com/M4M6KC01A' target='_blank'><img src='.github/assets/images/support.png' alt='Buy Me a Hot Chocolate at ko-fi.com' width="45%" /></a>
</p>

<p align="right">(<a href="#readme-top">back to top</a>)</p>

<!-- License Block -->

## :warning: License

The content of this repository is distributed under the GNU GPL-3.0 License. See `LICENSE` for more information.

<p align="right">(<a href="#readme-top">back to top</a>)</p>

<!-- Built With Block -->

## :hammer_and_wrench: Built With

- [Python](https://www.python.org/)
- [beautifulsoup4](https://www.crummy.com/software/BeautifulSoup/)
- [InquirerPy](https://inquirerpy.readthedocs.io/en/latest/)

<p align="right">(<a href="#readme-top">back to top</a>)</p>
